PlatformUtils class

Utility class for platform-specific functionality

Constructors

PlatformUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

canUseFilePicker bool
Check if file picker can be used on current platform
no setter
canUseGetX bool
Check if GetX can be used safely on current platform
no setter
canUseImagePicker bool
Check if image picker can be used on current platform
no setter
canUseYouTubePlayer bool
Check if YouTube player can be used on current platform
no setter
isAndroid bool
Check if the current platform is Android
no setter
isFuchsia bool
Check if the current platform is Fuchsia
no setter
isIOS bool
Check if the current platform is iOS
no setter
isLinux bool
Check if the current platform is Linux
no setter
isMacOS bool
Check if the current platform is macOS
no setter
isMobile bool
Check if the current platform is mobile (iOS or Android)
no setter
isWeb bool
Check if the current platform is web
no setter
isWindows bool
Check if the current platform is Windows
no setter
platformName String
Get platform name as string
no setter
supportsBackgroundProcesses bool
Check if platform supports background processes
no setter
supportsPushNotifications bool
Check if platform supports push notifications
no setter

Static Methods

getResponsiveWidth(double fallbackWidth) double
Get appropriate width calculation based on platform