MyTable<T> class

Inheritance

Constructors

MyTable({Key? key, required List<MyTableColumn<T>> columns, required List<T> data, double height = 500, double scrollbarThickness = 8.0, Radius? scrollbarRadius, Color? rowColor, bool loading = false, void onPressedRow(T value)?, bool hasMore = false, FutureOr<void> onLoadMore()?, List<MyTableAction<T>> actions = const [], bool wrapAction = true, String emptyText = 'Nenhum registro encontrado.'})
const

Properties

actions List<MyTableAction<T>>
final
columns List<MyTableColumn<T>>
final
data List<T>
final
emptyText String
final
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
final
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading bool
final
onLoadMore FutureOr<void> Function()?
final
onPressedRow → void Function(T value)?
final
rowColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarRadius Radius?
final
scrollbarThickness double
final
wrapAction bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MyTable<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited