MyTableAction<T> class

Constructors

MyTableAction({required String tooltip, required IconData icon, Color? color, bool disabled(T data)?, void onTap(T data)?})
const

Properties

color Color?
final
disabled bool Function(T data)?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
onTap → void Function(T data)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited