MyTablePaginationData class

Constructors

MyTablePaginationData({required int totalItems, required int? itemsPerPage, required int currentPage, void onPageChanged(int page)?, AlignmentGeometry alignment = Alignment.centerRight})
const

Properties

alignment AlignmentGeometry
final
currentPage int
final
hashCode int
The hash code for this object.
no setterinherited
itemsPerPage int?
final
onPageChanged → void Function(int page)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalItems int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited