ConectarSettings class

Constructors

ConectarSettings({Color primaryColor = ConectarColors.primary, Color backgroundColor = ConectarColors.surface, Color successColor = ConectarColors.success, Color textColor = ConectarColors.onSurface, Color borderColor = ConectarColors.outline, double cardRadius = 6, double paddingDefault = 16, bool showLogsOnWeb = false})

Properties

backgroundColor Color
final
borderColor Color
final
cardRadius double
final
hashCode int
The hash code for this object.
no setterinherited
paddingDefault double
final
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLogsOnWeb bool
final
successColor Color
final
textColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited