PaginatedModel<T extends BaseModel> class
- Available extensions
Constructors
-
PaginatedModel({List<
T> ? items, PaginationModel? pagination}) -
PaginatedModel.fromJson(Map<
String, dynamic> json, {List<T> customFromJson(List e)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
↔ List<
T> ? -
getter/setter pair
- pagination ↔ PaginationModel?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ini(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orderBy(
String field, {bool descending = false}) → PaginatedModel< T> -
Available on PaginatedModel<
Orders items by a specific fieldT> , provided by the PaginatedModelExtensions extension -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
where(
bool test(T item)) → PaginatedModel< T> -
Available on PaginatedModel<
Filters items using a custom test functionT> , provided by the PaginatedModelExtensions extension -
whereEqual(
String field, dynamic value) → PaginatedModel< T> -
Available on PaginatedModel<
Filters items by exact match on a specific fieldT> , provided by the PaginatedModelExtensions extension -
whereIn(
String field, List values) → PaginatedModel< T> -
Available on PaginatedModel<
Filters items where a field value is in a list of valuesT> , provided by the PaginatedModelExtensions extension -
whereMultiple(
Map< String, dynamic> conditions) → PaginatedModel<T> -
Available on PaginatedModel<
Filters items by multiple field-value pairs (AND condition)T> , provided by the PaginatedModelExtensions extension -
whereNotEqual(
String field, dynamic value) → PaginatedModel< T> -
Available on PaginatedModel<
Filters items by inequality on a specific fieldT> , provided by the PaginatedModelExtensions extension -
whereNotIn(
String field, List values) → PaginatedModel< T> -
Available on PaginatedModel<
Filters items where a field value is not in a list of valuesT> , provided by the PaginatedModelExtensions extension -
whereOperator(
String field, String operator, dynamic value) → PaginatedModel< T> -
Available on PaginatedModel<
Filters items using various comparison operatorsT> , provided by the PaginatedModelExtensions extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited