ApiConnector class
- Implemented types
Constructors
-
ApiConnector({required String baseUrl, String? token, List<
Interceptor> ? interceptors}) -
factory
Properties
- baseUrl → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interceptors
→ List<
Interceptor> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String?
-
final
Methods
-
delete(
BaseRequest request) → Future< BaseResponse> -
override
-
download(
BaseRequest request) → Future< BaseResponse> -
override
-
get(
BaseRequest request) → Future< BaseResponse> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
BaseRequest request) → Future< BaseResponse> -
override
-
post(
BaseRequest request, {bool useHeaders = true}) → Future< BaseResponse> -
override
-
put(
BaseRequest request, {bool useHeaders = true}) → Future< BaseResponse> -
override
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
upload(
BaseRequest request, {bool useHeaders = true}) → Future< BaseResponse> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited