IOSConfig class

iOS-specific configurations

Constructors

IOSConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

capabilities → const Map<String, bool>
iOS-specific capabilities
enableBackgroundRefresh → const bool
Enable background app refresh
enableBiometrics → const bool
Enable biometric authentication
enablePushNotifications → const bool
Enable push notifications
minimumVersion → const String
Minimum iOS version supported