MyTableColumn<T> class
Constructors
- MyTableColumn({required String name, String? tooltip, String builder(T data)?, Widget customCellBuilder(T data)?, Widget headerWidgetBuilder()?, TableColumnWidth? tableWidth, String cellTooptip(T data)?})
-
const
Properties
- builder → String Function(T data)?
-
final
- cellTooptip → String Function(T data)?
-
final
- customCellBuilder → Widget Function(T data)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerWidgetBuilder → Widget Function()?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableWidth → TableColumnWidth?
-
final
- tooltip → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited