ConectarDesignSystemWeb class
A web implementation of the ConectarDesignSystemPlatform of the ConectarDesignSystem plugin.
- Inheritance
-
- Object
- PlatformInterface
- ConectarDesignSystemPlatform
- ConectarDesignSystemWeb
Constructors
- ConectarDesignSystemWeb()
- Constructs a ConectarDesignSystemWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns a String containing the version of the platform.
override
-
getScreenDimensions(
) → Map< String, double> - Get screen dimensions for responsive design
-
isPWA(
) → bool - Check if running in PWA mode
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsLocalStorage(
) → bool - Check if the web environment supports specific features
-
supportsSessionStorage(
) → bool - Check if the web environment supports session storage
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void